@@ -1,5 +1,20 @@
 """Koopman operator identification library in Python."""
 
+from .centers import (
+    Centers,
+    ClusterCenters,
+    DataCenters,
+    GaussianMixtureRandomCenters,
+    GaussianRandomCenters,
+    GridCenters,
+    QmcCenters,
+    UniformRandomCenters,
+)
+from .kernel_approximation import (
+    KernelApproximation,
+    RandomBinningKernelApprox,
+    RandomFourierKernelApprox,
+)
 from .koopman_pipeline import (
     EpisodeDependentLiftingFn,
     EpisodeIndependentLiftingFn,
@@ -17,15 +32,20 @@ from .koopman_pipeline import (
 )
 from .lifting_functions import (
     BilinearInputLiftingFn,
+    ConstantLiftingFn,
     DelayLiftingFn,
     PolynomialLiftingFn,
+    RbfLiftingFn,
+    KernelApproxLiftingFn,
     SkLearnLiftingFn,
 )
-from .regressors import Dmd, Dmdc, Edmd
+from .regressors import Dmd, Dmdc, Edmd, EdmdMeta
 from .tsvd import Tsvd
 from .util import (
     AnglePreprocessor,
+    example_data_duffing,
     example_data_msd,
+    example_data_pendulum,
     example_data_vdp,
     random_input,
     random_state,
