@@ -41,6 +41,8 @@ class AnglePreprocessor(koopman_pipeline.EpisodeIndependentLiftingFn):
         Minimum number of samples needed to use the transformer.
     episode_feature_ : bool
         Indicates if episode feature was present during :func:`fit`.
+    feature_names_in_ : np.ndarray
+        Array of input feature name strings.
 
     Warnings
     --------
@@ -137,6 +139,37 @@ class AnglePreprocessor(koopman_pipeline.EpisodeIndependentLiftingFn):
     def _validate_parameters(self) -> None:
         pass  # No constructor parameters need validation.
 
+    def _transform_feature_names(
+        self,
+        feature_names: np.ndarray,
+        format: str = None,
+    ) -> np.ndarray:
+        # noqa: D102
+        if format == 'latex':
+            cos = r'\cos'
+            sin = r'\sin'
+            pre = '{'
+            post = '}'
+        else:
+            cos = 'cos'
+            sin = 'sin'
+            pre = ''
+            post = ''
+        names_out = []
+        if self.episode_feature_:
+            names_out.append(feature_names[0])
+        for k in range(self.n_states_in_ + self.n_inputs_in_):
+            name_idx = k + 1 if self.episode_feature_ else k
+            if self.angles_in_[k]:
+                names_out.append(
+                    f'{cos}{pre}({feature_names[name_idx]}){post}')
+                names_out.append(
+                    f'{sin}{pre}({feature_names[name_idx]}){post}')
+            else:
+                names_out.append(feature_names[name_idx])
+        feature_names_out = np.array(names_out, dtype=object)
+        return feature_names_out
+
 
 def random_state(low, high, rng=None):
     """Generate a random initial state.
@@ -314,6 +347,7 @@ def example_data_msd() -> Dict[str, Any]:
         'n_inputs': n_inputs,
         'episode_feature': episode_feature,
         't': t_sim,
+        'dynamic_model': msd,
     }
 
 
@@ -379,4 +413,148 @@ def example_data_vdp() -> Dict[str, Any]:
         'n_inputs': n_inputs,
         'episode_feature': episode_feature,
         't': t_sim,
+        'dynamic_model': vdp,
+    }
+
+
+def example_data_pendulum() -> Dict[str, Any]:
+    """Get example pendulum data.
+
+    Always starts with zero initial velocity.
+
+    Returns
+    -------
+    Dict[str, Any]
+        Sample pendulum data.
+    """
+    # Create pendulum object
+    t_step = 0.01
+    pend = dynamic_models.Pendulum(mass=1, length=1, damping=1e-1)
+    # Initial conditions
+    t_range = (0, 20)
+    t_sim = np.arange(*t_range, t_step)
+    n_ep = 50
+    conditions = [(i, np.array([np.pi * i * 0.1, 0])) for i in range(n_ep)]
+    X_pend_lst = []
+    # Loop over initial conditions and inputs
+    for ep, x0 in conditions:
+        # Simulate ODE
+        t, x = pend.simulate(
+            t_range=t_range,
+            t_step=t_step,
+            x0=x0,
+            u=lambda t: 0,
+        )
+        # Format the data
+        X_pend_lst.append(np.hstack((
+            ep * np.ones((t.shape[0], 1)),
+            x,
+        )))
+    # Stack data and return
+    X_pend = np.vstack(X_pend_lst)
+    valid_ep = [5, 25, 45]
+    train_ep = list(set(range(n_ep)) - set(valid_ep))
+    valid_idx = np.where(np.in1d(X_pend[:, 0], valid_ep))[0]
+    train_idx = np.where(np.in1d(X_pend[:, 0], train_ep))[0]
+    X_train = X_pend[train_idx, :]
+    X_valid = X_pend[valid_idx, :]
+    n_inputs = 0
+    episode_feature = True
+    x0_valid = koopman_pipeline.extract_initial_conditions(
+        X_valid,
+        n_inputs=n_inputs,
+        episode_feature=episode_feature,
+    )
+    u_valid = koopman_pipeline.extract_input(
+        X_valid,
+        n_inputs=n_inputs,
+        episode_feature=episode_feature,
+    )
+    return {
+        'X_train': X_train,
+        'X_valid': X_valid,
+        'x0_valid': x0_valid,
+        'u_valid': u_valid,
+        'n_inputs': n_inputs,
+        'episode_feature': episode_feature,
+        't': t_sim,
+        'dynamic_model': pend,
+    }
+
+
+def example_data_duffing() -> Dict[str, Any]:
+    """Get example Duffing oscillator data.
+
+    Parameters from [WHDKR16]_.
+
+    Returns
+    -------
+    Dict[str, Any]
+        Sample Duffing oscillator data.
+    """
+    # Create Duffing oscillator object
+    t_step = 0.1
+    do = dynamic_models.DuffingOscillator(alpha=1, beta=-1, delta=0.2)
+    # Initial conditions
+    t_range = (0, 20)
+    t_sim = np.arange(*t_range, t_step)
+    n_ep = 50
+    X_do_lst = []
+    # Loop over initial conditions and inputs
+    rng = np.random.default_rng(1234)
+    for ep in range(n_ep):
+        # Simulate ODE
+        x0 = random_state(
+            np.array([-1, -1]),
+            np.array([1, 1]),
+            rng=rng,
+        )
+        a = rng.uniform(0, 0.3)
+
+        def u(t):
+            """Input."""
+            return a * np.cos(t)
+
+        t, x = do.simulate(
+            t_range=t_range,
+            t_step=t_step,
+            x0=x0,
+            u=u,
+        )
+        # Format the data
+        X_do_lst.append(
+            np.hstack((
+                ep * np.ones((t.shape[0], 1)),
+                x,
+                u(t).reshape(-1, 1),
+            )))
+    # Stack data and return
+    X_do = np.vstack(X_do_lst)
+    valid_ep = [n_ep - 3, n_ep - 2, n_ep - 1]
+    train_ep = list(set(range(n_ep)) - set(valid_ep))
+    valid_idx = np.where(np.in1d(X_do[:, 0], valid_ep))[0]
+    train_idx = np.where(np.in1d(X_do[:, 0], train_ep))[0]
+    X_train = X_do[train_idx, :]
+    X_valid = X_do[valid_idx, :]
+    n_inputs = 1
+    episode_feature = True
+    x0_valid = koopman_pipeline.extract_initial_conditions(
+        X_valid,
+        n_inputs=n_inputs,
+        episode_feature=episode_feature,
+    )
+    u_valid = koopman_pipeline.extract_input(
+        X_valid,
+        n_inputs=n_inputs,
+        episode_feature=episode_feature,
+    )
+    return {
+        'X_train': X_train,
+        'X_valid': X_valid,
+        'x0_valid': x0_valid,
+        'u_valid': u_valid,
+        'n_inputs': n_inputs,
+        'episode_feature': episode_feature,
+        't': t_sim,
+        'dynamic_model': do,
     }
